# Mazane - Modern Admin Dashboard

A modern, responsive admin dashboard built with React, TypeScript, and Vite. This project provides a comprehensive solution for managing users, products, orders, and analytics.

## Features

- 🎨 Modern and responsive UI with Tailwind CSS
- 📊 Interactive charts and analytics
- 👥 User management system
- 📦 Product management
- 🛍️ Order tracking
- 🔐 Authentication and authorization
- 🌙 Dark/Light mode
- 📱 Mobile responsive design

## Tech Stack

- React 18
- TypeScript
- Vite
- Tailwind CSS
- React Query
- React Router
- Chart.js
- Zustand (State Management)
- React Hook Form
- Zod (Validation)

## Getting Started

### Prerequisites

- Node.js (v18 or higher)
- npm or yarn

### Installation

1. Clone the repository:

```bash
git clone https://github.com/hosseintaromi/mazane.git
cd mazane
```

2. Install dependencies:

```bash
npm install
# or
yarn install
```

3. Start the development server:

```bash
npm run dev
# or
yarn dev
```

4. Open [http://localhost:5173](http://localhost:5173) in your browser.

## Project Structure

```
src/
├── components/     # Reusable UI components
├── contexts/       # React contexts
├── hooks/         # Custom React hooks
├── pages/         # Page components
├── services/      # API services
├── stores/        # State management
├── types/         # TypeScript types
└── utils/         # Utility functions
```

## Available Scripts

- `npm run dev` - Start development server
- `npm run build` - Build for production
- `npm run preview` - Preview production build
- `npm run lint` - Run ESLint
- `npm run type-check` - Run TypeScript type checking

## Contributing

1. Fork the repository
2. Create your feature branch (`git checkout -b feature/amazing-feature`)
3. Commit your changes (`git commit -m 'feat(feature): add amazing feature'`)
4. Push to the branch (`git push origin feature/amazing-feature`)
5. Open a Pull Request

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Contact

Hossein Taromi - [@hosseintaromi](https://github.com/hosseintaromi)

Project Link: [https://github.com/hosseintaromi/mazane](https://github.com/hosseintaromi/mazane)
