import { TrendingUp, TrendingDown } from 'lucide-react';

interface StatsCardProps {
    title: string;
    value: string | number;
    change?: number;
    icon: any;
    color?: string;
}

export const StatsCard = ({
    title,
    value,
    change,
    icon: Icon,
    color = 'blue'
}: StatsCardProps) => {
    const colorClasses = {
        blue: 'bg-blue-500',
        green: 'bg-green-500',
        yellow: 'bg-yellow-500',
        red: 'bg-red-500',
        purple: 'bg-purple-500',
    };

    const isPositive = change && change > 0;
    const isNegative = change && change < 0;

    return (
        <div className="card p-6 animate-fade-in">
            <div className="flex items-center">
                <div className="flex-shrink-0">
                    <div className={`p-3 rounded-lg ${colorClasses[color as keyof typeof colorClasses] || colorClasses.blue}`}>
                        <Icon className="h-6 w-6 text-white" />
                    </div>
                </div>
                <div className="mr-5 w-0 flex-1">
                    <dl>
                        <dt className="text-sm font-medium text-gray-500 dark:text-gray-400 truncate">
                            {title}
                        </dt>
                        <dd className="flex items-baseline">
                            <div className="text-2xl font-semibold text-gray-900 dark:text-gray-100">
                                {typeof value === 'number' ? value.toLocaleString() : value}
                            </div>
                            {change !== undefined && (
                                <div className={`mr-2 flex items-baseline text-sm font-semibold ${isPositive ? 'text-green-600' : isNegative ? 'text-red-600' : 'text-gray-500'
                                    }`}>
                                    {isPositive && <TrendingUp className="h-4 w-4 flex-shrink-0 self-center ml-1" />}
                                    {isNegative && <TrendingDown className="h-4 w-4 flex-shrink-0 self-center ml-1" />}
                                    <span className="sr-only">
                                        {isPositive ? 'افزایش' : 'کاهش'}
                                    </span>
                                    {Math.abs(change)}%
                                </div>
                            )}
                        </dd>
                    </dl>
                </div>
            </div>
        </div>
    );
}; 