import { forwardRef } from 'react';
import { clsx } from 'clsx';

interface InputProps {
    label?: string;
    error?: string;
    type?: string;
    placeholder?: string;
    className?: string;
    icon?: any;
    disabled?: boolean;
}

export const Input = forwardRef<HTMLInputElement, InputProps>(
    ({ label, error, type = 'text', placeholder, className, icon: Icon, disabled, ...props }, ref) => {
        return (
            <div className="space-y-1">
                {label && (
                    <label className="block text-sm font-medium text-gray-700 dark:text-gray-300">
                        {label}
                    </label>
                )}
                <div className="relative">
                    {Icon && (
                        <div className="absolute inset-y-0 right-0 pr-3 flex items-center pointer-events-none">
                            <Icon className="h-5 w-5 text-gray-400" />
                        </div>
                    )}
                    <input
                        ref={ref}
                        type={type}
                        placeholder={placeholder}
                        disabled={disabled}
                        className={clsx(
                            'input',
                            Icon && 'pr-10',
                            error && 'border-red-500 dark:border-red-500 focus:ring-red-500',
                            disabled && 'opacity-50 cursor-not-allowed',
                            className
                        )}
                        {...props}
                    />
                </div>
                {error && (
                    <p className="text-sm text-red-600 dark:text-red-400">
                        {error}
                    </p>
                )}
            </div>
        );
    }
);

Input.displayName = 'Input'; 