import { useState } from 'react';
import { Search, Filter, ShoppingCart, TrendingUp } from 'lucide-react';
import { Table } from '../components/ui/Table';
import { Button } from '../components/ui/Button';
import { Pagination } from '../components/ui/Pagination';
import { TableColumn } from '../types';

const allOrders = [
    { id: 1001, customer: 'علی احمدی', products: '۳ محصول', amount: '۴۵,۰۰۰,۰۰۰', status: 'تحویل شده', date: '۱۴۰۲/۰۸/۱۵' },
    { id: 1002, customer: 'فاطمه حسینی', products: '۱ محصول', amount: '۲۵,۰۰۰,۰۰۰', status: 'در حال پردازش', date: '۱۴۰۲/۰۸/۱۴' },
    { id: 1003, customer: 'محمد رضایی', products: '۲ محصول', amount: '۳۲,۰۰۰,۰۰۰', status: 'ارسال شده', date: '۱۴۰۲/۰۸/۱۳' },
    { id: 1004, customer: 'زهرا کریمی', products: '۵ محصول', amount: '۱۲۰,۰۰۰,۰۰۰', status: 'تحویل شده', date: '۱۴۰۲/۰۸/۱۲' },
    { id: 1005, customer: 'حسن نوری', products: '۱ محصول', amount: '۱۸,۰۰۰,۰۰۰', status: 'لغو شده', date: '۱۴۰۲/۰۸/۱۱' },
    { id: 1006, customer: 'مریم صادقی', products: '۴ محصول', amount: '۸۵,۰۰۰,۰۰۰', status: 'در حال پردازش', date: '۱۴۰۲/۰۸/۱۰' },
    { id: 1007, customer: 'احمد قاسمی', products: '۲ محصول', amount: '۳۸,۰۰۰,۰۰۰', status: 'ارسال شده', date: '۱۴۰۲/۰۸/۰۹' },
    { id: 1008, customer: 'سارا محمدی', products: '۳ محصول', amount: '۶۲,۰۰۰,۰۰۰', status: 'تحویل شده', date: '۱۴۰۲/۰۸/۰۸' },
    { id: 1009, customer: 'رضا کریمی', products: '۱ محصول', amount: '۱۵,۰۰۰,۰۰۰', status: 'در حال پردازش', date: '۱۴۰۲/۰۸/۰۷' },
    { id: 1010, customer: 'نرگس احمدی', products: '۶ محصول', amount: '۱۴۵,۰۰۰,۰۰۰', status: 'تحویل شده', date: '۱۴۰۲/۰۸/۰۶' },
];

export const Orders = () => {
    const [searchTerm, setSearchTerm] = useState('');
    const [loading, setLoading] = useState(false);
    const [currentPage, setCurrentPage] = useState(1);
    const itemsPerPage = 6;

    const columns: TableColumn[] = [
        { key: 'id', label: 'شماره سفارش', sortable: true },
        { key: 'customer', label: 'مشتری', sortable: true },
        { key: 'products', label: 'محصولات' },
        {
            key: 'amount',
            label: 'مبلغ',
            render: (value) => (
                <span className="font-medium text-gray-900 dark:text-gray-100">
                    {value} تومان
                </span>
            )
        },
        {
            key: 'status',
            label: 'وضعیت',
            render: (value) => (
                <span className={`px-2 py-1 rounded-full text-xs font-medium ${value === 'تحویل شده'
                        ? 'bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-200'
                        : value === 'ارسال شده'
                            ? 'bg-blue-100 text-blue-800 dark:bg-blue-900 dark:text-blue-200'
                            : value === 'در حال پردازش'
                                ? 'bg-yellow-100 text-yellow-800 dark:bg-yellow-900 dark:text-yellow-200'
                                : 'bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-200'
                    }`}>
                    {value}
                </span>
            )
        },
        { key: 'date', label: 'تاریخ سفارش', sortable: true },
        {
            key: 'actions',
            label: 'عملیات',
            render: (_, row) => (
                <div className="flex space-x-2">
                    <Button
                        size="sm"
                        variant="secondary"
                        onClick={() => handleViewOrder(row)}
                    >
                        مشاهده
                    </Button>
                    <Button
                        size="sm"
                        variant="primary"
                        onClick={() => handleEditOrder(row)}
                    >
                        ویرایش
                    </Button>
                </div>
            )
        }
    ];

    const filteredOrders = allOrders.filter((order: any) =>
        order.customer.toLowerCase().includes(searchTerm.toLowerCase()) ||
        order.id.toString().includes(searchTerm)
    );

    const totalPages = Math.ceil(filteredOrders.length / itemsPerPage);
    const startIndex = (currentPage - 1) * itemsPerPage;
    const paginatedOrders = filteredOrders.slice(startIndex, startIndex + itemsPerPage);

    const handleViewOrder = (order: any) => {
        console.log('Viewing order:', order);
    };

    const handleEditOrder = (order: any) => {
        console.log('Editing order:', order);
    };

    const totalRevenue = allOrders.reduce((sum, order) => {
        const amount = parseInt(order.amount.replace(/[,]/g, ''));
        return sum + amount;
    }, 0);

    return (
        <div className="p-6 space-y-6">
            <div className="flex flex-col sm:flex-row items-start sm:items-center justify-between gap-4">
                <div>
                    <h1 className="text-2xl font-bold text-gray-900 dark:text-gray-100">
                        مدیریت سفارشات
                    </h1>
                    <p className="text-gray-600 dark:text-gray-400 mt-1">
                        {filteredOrders.length} سفارش یافت شد
                    </p>
                </div>

                <div className="flex items-center space-x-4">
                    <Button variant="secondary">
                        <Filter className="h-4 w-4 ml-2" />
                        فیلتر
                    </Button>
                </div>
            </div>

            <div className="grid grid-cols-1 md:grid-cols-4 gap-6 mb-6">
                <div className="bg-white dark:bg-gray-800 p-4 rounded-lg shadow">
                    <div className="flex items-center">
                        <ShoppingCart className="h-8 w-8 text-blue-600" />
                        <div className="mr-3">
                            <p className="text-sm font-medium text-gray-600 dark:text-gray-400">کل سفارشات</p>
                            <p className="text-2xl font-bold text-gray-900 dark:text-gray-100">{allOrders.length}</p>
                        </div>
                    </div>
                </div>

                <div className="bg-white dark:bg-gray-800 p-4 rounded-lg shadow">
                    <div className="flex items-center">
                        <TrendingUp className="h-8 w-8 text-green-600" />
                        <div className="mr-3">
                            <p className="text-sm font-medium text-gray-600 dark:text-gray-400">تحویل شده</p>
                            <p className="text-2xl font-bold text-gray-900 dark:text-gray-100">
                                {allOrders.filter(o => o.status === 'تحویل شده').length}
                            </p>
                        </div>
                    </div>
                </div>

                <div className="bg-white dark:bg-gray-800 p-4 rounded-lg shadow">
                    <div className="flex items-center">
                        <ShoppingCart className="h-8 w-8 text-yellow-600" />
                        <div className="mr-3">
                            <p className="text-sm font-medium text-gray-600 dark:text-gray-400">در انتظار</p>
                            <p className="text-2xl font-bold text-gray-900 dark:text-gray-100">
                                {allOrders.filter(o => o.status === 'در حال پردازش').length}
                            </p>
                        </div>
                    </div>
                </div>

                <div className="bg-white dark:bg-gray-800 p-4 rounded-lg shadow">
                    <div className="flex items-center">
                        <TrendingUp className="h-8 w-8 text-purple-600" />
                        <div className="mr-3">
                            <p className="text-sm font-medium text-gray-600 dark:text-gray-400">کل فروش</p>
                            <p className="text-xl font-bold text-gray-900 dark:text-gray-100">
                                {totalRevenue.toLocaleString()} تومان
                            </p>
                        </div>
                    </div>
                </div>
            </div>

            <div className="card p-6">
                <div className="mb-6">
                    <div className="relative">
                        <div className="absolute inset-y-0 right-0 pr-3 flex items-center pointer-events-none">
                            <Search className="h-5 w-5 text-gray-400" />
                        </div>
                        <input
                            type="text"
                            placeholder="جستجو در سفارشات..."
                            value={searchTerm}
                            onChange={(e) => setSearchTerm(e.target.value)}
                            className="input pr-10 max-w-md"
                        />
                    </div>
                </div>

                <div className="bg-white dark:bg-gray-800 rounded-lg overflow-hidden">
                    <Table
                        columns={columns}
                        data={paginatedOrders}
                        loading={loading}
                    />
                    <Pagination
                        currentPage={currentPage}
                        totalPages={totalPages}
                        onPageChange={setCurrentPage}
                        itemsPerPage={itemsPerPage}
                        totalItems={filteredOrders.length}
                    />
                </div>
            </div>
        </div>
    );
}; 